Research on Tabular Deep Learning
=================================

:code:`rtdl` is a PyTorch-based package providing a user-friendly API for the main models and concepts from our `papers <https://github.com/Yura52/rtdl#papers-and-projects>`_.

Installation
------------

.. code-block::

   pip install rtdl

Documentation
-------------

- See the API reference in the left sidebar
- Colab example: https://colab.research.google.com/github/Yura52/rtdl/blob/main/examples/rtdl.ipynb

.. toctree::
   :caption: API REFERENCE
   :hidden:

   rtdl
   rtdl_data

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
